@@ -67,15 +67,12 @@ else
       print_failed_and_die
     fi
 
-    print_msg "SSH stopped" "OK"
-
     exit 2
   else
     # SSH stopped, run it
     action="enable"
     step=":$(start sshd 2>&1 >/dev/null)"
     if [ `pidof sshd` -gt "0" ] ; then
-      print_msg "SSH started" "OK"
       exit 0
     fi
     print_failed_and_die
